pub fn transform<T: CsdifMapper>(input: &T) -> Result<CsdifDocument, CsdifError>Expand description
Generic transformation entry point.
This function delegates to the trait implementation of the input type.
pub fn transform<T: CsdifMapper>(input: &T) -> Result<CsdifDocument, CsdifError>Generic transformation entry point.
This function delegates to the trait implementation of the input type.