CsdifMapper

Trait CsdifMapper 

pub trait CsdifMapper {
    // Required method
    fn to_csdif(&self) -> Result<CsdifDocument, CsdifError>;
}
Trait for mapping external data into a CSDIF document.

This trait should be implemented by any adapter that wants to convert its own input format into a valid CSDIF structure.

Required Methods

fn to_csdif(&self) -> Result<CsdifDocument, CsdifError>

Converts the implementing type into a CSDIF document.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors